@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0605';
+our $VERSION = '0.0606';
 
 use Moo;
 use strictures 2;
@@ -68,6 +68,25 @@ has scale => (
 sub _build_scale {
     my ($self) = @_;
     my @scale = get_scale_notes($self->scale_note, $self->scale_name);
+    my %equiv = (
+        'C#'  => 'Db',
+        'D#'  => 'Eb',
+        'E#'  => 'F',
+        'F#'  => 'Gb',
+        'G#'  => 'Ab',
+        'A#'  => 'Bb',
+        'B#'  => 'C',
+        'Cb'  => 'B',
+        'Dbb' => 'C',
+        'Ebb' => 'D',
+        'Fb'  => 'E',
+        'Gbb' => 'F',
+        'Abb' => 'G',
+        'Bbb' => 'A',
+    );
+    for (@scale) {
+        $_ = $equiv{$_} if exists $equiv{$_};
+    }
     print 'Scale: ', ddc(\@scale) if $self->verbose;
     return \@scale;
 }
@@ -334,7 +353,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0605
+version 0.0606
 
 =head1 SYNOPSIS
 
@@ -577,7 +596,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Gene Boggs.
+This software is copyright (c) 2020-2023 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
